## Features
- Under active development!
- Written in Rust, btw xD
- A multithreaded Runtime
- Extensible
- A simple API
- Sync and Async Function Support
- Dynamic URL Routing
- Multi Core Scaling
- WebSocket!
- Hot Reloading (Still experimental)
- Query Params
- Events (Startup and Shutdown)
- Community First and truly FOSS!

